@@ -26,7 +26,7 @@ use Carp;
 
 use Astro::FITS::Header::Item;
 
-$VERSION = 3.03;
+$VERSION = 3.08;
 
 # Operator overloads
 use overload '""' => "stringify",
@@ -738,7 +738,7 @@ sub merge_primary {
   # Go through all the items building up a hash indexed
   # by KEYWORD pointing to an array of items with that keyword
   # and an array of unique keywords in the original order they
-  # appeared first. COMMENT and UNDEF items are stored in the
+  # appeared first. COMMENT items are stored in the
   # hash as complete cards.
   # HEADER items are currently dropped on the floor.
   my @order;
@@ -751,7 +751,7 @@ sub merge_primary {
       if (!defined $type || $type eq 'BLANK') {
         # blank line so skip it
         next;
-      } elsif ($type eq 'COMMENT' || $type eq 'UNDEF') {
+      } elsif ($type eq 'COMMENT') {
         $key = $item->card;
       } elsif ($type eq 'HEADER') {
         next;
@@ -1505,6 +1505,7 @@ sub CLEAR {
   $self->{LOOKUP} = { };
   $self->{LASTKEY} = undef;
   $self->{SEENKEY} = undef;
+  $self->{SUBHDRS} = [ ];
 }
 
 # implements keys() and each()
@@ -1512,7 +1513,7 @@ sub FIRSTKEY {
   my $self = shift;
   $self->{LASTKEY} = 0;
   $self->{SEENKEY} = {};
-  return undef unless @{$self->{HEADER}};
+  return $self->_check_for_subhdr() unless @{$self->{HEADER}};
   return ${$self->{HEADER}}[0]->keyword();
 }
 
@@ -1603,7 +1604,7 @@ use strict;
 use Carp;
 
 our $VERSION;
-$VERSION = '3.01';
+$VERSION = '3.08';
 
 # Class wrapper for subhdrs tie. Not (yet) a public interface
 # we simply need a class that we can tie the subhdrs array to.
